package main

import (
	"flag"
	"log"
	"net"
	"net/http"

	"github.com/gorilla/websocket"
)

var addr = flag.String("addr", "localhost:8080", "http service address")
var target = flag.String("target", "localhost:2137", "target wled UDP port")

var upgrader = websocket.Upgrader{} // use default options

func stream(w http.ResponseWriter, r *http.Request) {
	c, err := upgrader.Upgrade(w, r, nil)
	if err != nil {
		log.Print("upgrade:", err)
		return
	}
	conn, err := net.Dial("udp", *target)

	defer c.Close()
	for {
		mt, message, err := c.ReadMessage()
		if err != nil {
			log.Println("read:", err)
			break
		}
		log.Printf("recv: %d mt: %s", len(message), mt)
		conn.Write(message)
		// err = c.WriteMessage(mt, message)
		if err != nil {
			log.Println("write:", err)
			break
		}
	}
}

func home(w http.ResponseWriter, r *http.Request) {
	http.ServeFile(w, r, "frontend.html")
}

func main() {
	flag.Parse()
	log.SetFlags(0)
	http.HandleFunc("/stream", stream)
	http.HandleFunc("/", home)
	upgrader.CheckOrigin = func(r *http.Request) bool { return true }
	log.Printf("Listening on %s...", *addr)
	log.Fatal(http.ListenAndServe(*addr, nil))
}
